@@ -21,10 +21,14 @@ from nextcodecli.workflow.cmdutils import get_processes_table, process_status_to
 
 def check_for_broken_job(job):
     status = job.status
+    max_diff = 60.0
+    # jobs with dedicated storage_type can take 5-6 minutes to start so let's wait 10 minutes to be sure
+    if job.details['launch_config']['storage_type'] == 'dedicated':
+        max_diff = 600.0
     if status != 'PENDING':
         return False
     diff = (datetime.datetime.utcnow() - job.submit_date).total_seconds()
-    if diff >= 60.0:
+    if diff >= max_diff:
         secho(
             "\nJob has been in status '%s' for %.0f seconds. Something might be wrong."
             % (status, diff),
@@ -97,20 +101,22 @@ def inspect(ctx, is_raw):
         if job_status in ('PENDING', 'STARTED'):
             secho("Nextflow executor pod not Found. This job is not running!", fg='red')
     else:
-        status = executor_pod['status']
-        container_statuses = status['container_statuses']
-        pod_state = {}
-        if container_statuses:
-            pod_state = container_statuses[0]['state']
+
         node_name = executor_pod['spec']['node_name']
         print_tab('Executor node name', node_name)
         secho("\nExecutor Pod State:", bold=True)
-        _keys = ['running', 'terminated', 'waiting']
-        keys = []
-        for k in _keys:
-            if pod_state.get(k):
-                keys.append(k)
-        output_pretty_json(pod_state, keys=keys)
+
+        if executor_pod['status']['container_statuses']:
+            pod_state = executor_pod['status']['container_statuses'][0]['state']
+            _keys = ['running', 'terminated', 'waiting']
+            keys = []
+            for k in _keys:
+                if pod_state.get(k):
+                    keys.append(k)
+            output_pretty_json(pod_state, keys=keys)
+        elif executor_pod['status']['conditions']:
+            output_pretty_json(executor_pod['status'], ['conditions'])
+
         echo(
             "Hint: You can view latest logs from this pod with: 'nextcode workflow job {} logs pod'".format(
                 workflow_job.job_id
