@@ -6,11 +6,13 @@ from click import echo, secho, pass_context, command, argument, option
 import hjson
 import logging
 import subprocess
+from collections import OrderedDict
 
 from nextcode.packagelocal import package_and_upload
 from nextcode.exceptions import ServerError, UploadError
 
 from nextcodecli.utils import abort
+from nextcodecli.utils import find_aws_credentials
 
 log = logging.getLogger(__name__)
 
@@ -36,6 +38,7 @@ log = logging.getLogger(__name__)
 )
 @option('-d', '--description', help='A human readable description of the job')
 @option('--storage_type', help="Overrides the pipeline storage type for the run")
+@option('-c', '--credentials', help="Credentials to forward to workflow-service", multiple=True)
 @option('--executor_memory_mb', help='Override the memory limit of the nextflow executor')
 @pass_context
 def run(
@@ -53,6 +56,7 @@ def run(
     trace,
     description,
     storage_type,
+    credentials,
     executor_memory_mb,
 ):
     """
@@ -65,6 +69,7 @@ def run(
     If you are running against a debug server that allows direct script execution you
     can use 'custom' for pipeline_name.
     """
+    credentials = creds_to_dict(credentials)
     manifest = {}
     params = {}
     if job_filename:
@@ -77,6 +82,7 @@ def run(
         profile = profile or manifest.get('profile')
         context = context or manifest.get('context')
         params = manifest.get('params', {})
+        credentials = credentials or manifest.get('credentials', {})
     try:
         override_params = {}
         for p in parameters:
@@ -95,6 +101,13 @@ def run(
         dict(params),
     )
 
+    creds = {}
+    for upload_name, local_name in credentials.items():
+        cred = find_aws_credentials(local_name)
+        creds[upload_name] = {}
+        creds[upload_name]['aws_access_key_id'] = cred['aws_access_key_id']
+        creds[upload_name]['aws_secret_access_key'] = cred['aws_secret_access_key']
+
     if not project_name:
         abort("You must specify PROJECT_NAME")
     if pipeline_name == 'custom' or not pipeline_name:
@@ -136,6 +149,7 @@ def run(
             trace,
             context=context,
             description=description,
+            credentials=creds,
             storage_type=storage_type,
             executor_memory_mb=int(executor_memory_mb) if executor_memory_mb else None,
         )
@@ -149,3 +163,19 @@ def run(
         cmd = ['nextcode', 'workflow', 'job', str(job_id), 'watch']
         echo("Executing %s..." % ' '.join(cmd))
         subprocess.call(cmd)
+
+
+def creds_to_dict(credentials):
+    """
+    convert a list of string of the form ['upload=joe', 'download=joe']
+    to an  ordered dict of the form {'upload': 'joe', 'download': 'joe'}
+    """
+    ret = OrderedDict()
+    # credentials are supplied on the form 'upload=joe'
+    # 'joe' being the local profile in ~/.aws/credentials
+    # and 'upload' being the name we give the credentials
+    # when forwarding to the workflow-service
+    for cred in credentials:
+        key, value = cred.split('=')
+        ret[key] = value
+    return ret
